pub struct StatueBonusSlot {
pub attribute_id: AttributeId,
pub grade_id: StatueBonusGradeId,
pub is_locked: bool,
}Expand description
Один заполненный слот на вкладке статуи
Fields
attribute_id: AttributeIdgrade_id: StatueBonusGradeIdis_locked: boolTrait Implementations
Sourceimpl Clone for StatueBonusSlot
impl Clone for StatueBonusSlot
Sourcefn clone(&self) -> StatueBonusSlot
fn clone(&self) -> StatueBonusSlot
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatueBonusSlot
impl Debug for StatueBonusSlot
Sourceimpl Default for StatueBonusSlot
impl Default for StatueBonusSlot
Sourcefn default() -> StatueBonusSlot
fn default() -> StatueBonusSlot
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StatueBonusSlot
impl<'de> Deserialize<'de> for StatueBonusSlot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for StatueBonusSlot
impl Hash for StatueBonusSlot
Sourceimpl JsonSchema for StatueBonusSlot
impl JsonSchema for StatueBonusSlot
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StatueBonusSlot
impl PartialEq for StatueBonusSlot
Sourceimpl Serialize for StatueBonusSlot
impl Serialize for StatueBonusSlot
Sourceimpl Tsify for StatueBonusSlot
impl Tsify for StatueBonusSlot
const DECL: &'static str = "/**\n * \u{41e}\u{434}\u{438}\u{43d} \u{437}\u{430}\u{43f}\u{43e}\u{43b}\u{43d}\u{435}\u{43d}\u{43d}\u{44b}\u{439} \u{441}\u{43b}\u{43e}\u{442} \u{43d}\u{430} \u{432}\u{43a}\u{43b}\u{430}\u{434}\u{43a}\u{435} \u{441}\u{442}\u{430}\u{442}\u{443}\u{438}\n */\nexport interface StatueBonusSlot {\n attribute_id: AttributeId;\n grade_id: StatueBonusGradeId;\n is_locked: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for StatueBonusSlot
impl StructuralPartialEq for StatueBonusSlot