pub struct StatueSet {
pub name: String,
pub slots: StatueSlotsMap,
}Expand description
Один сет (вкладка) статуи — Set 1 / Set 2 / Set 3
Fields
name: Stringslots: StatueSlotsMapTrait Implementations
Sourceimpl<'de> Deserialize<'de> for StatueSet
impl<'de> Deserialize<'de> for StatueSet
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatueSet
impl JsonSchema for StatueSet
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for StatueSet
impl Tsify for StatueSet
const DECL: &'static str = "/**\n * \u{41e}\u{434}\u{438}\u{43d} \u{441}\u{435}\u{442} (\u{432}\u{43a}\u{43b}\u{430}\u{434}\u{43a}\u{430}) \u{441}\u{442}\u{430}\u{442}\u{443}\u{438} \u{2014} Set 1 / Set 2 / Set 3\n */\nexport interface StatueSet {\n name: string;\n slots: StatueSlotsMap;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for StatueSet
impl StructuralPartialEq for StatueSet