pub struct StatueSlotsMap(pub BTreeMap<u8, StatueBonusSlot>);Expand description
Карта слотов статуи: ключ — индекс слота, значение — заполненный слот. Отсутствующий ключ означает, что слот ещё не был прокатан (pending).
Tuple Fields
0: BTreeMap<u8, StatueBonusSlot>Trait Implementations
Sourceimpl Clone for StatueSlotsMap
impl Clone for StatueSlotsMap
Sourcefn clone(&self) -> StatueSlotsMap
fn clone(&self) -> StatueSlotsMap
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for StatueSlotsMap
impl CustomType for StatueSlotsMap
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for StatueSlotsMap
impl Debug for StatueSlotsMap
Sourceimpl Default for StatueSlotsMap
impl Default for StatueSlotsMap
Sourcefn default() -> StatueSlotsMap
fn default() -> StatueSlotsMap
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StatueSlotsMap
impl<'de> Deserialize<'de> for StatueSlotsMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatueSlotsMap
impl JsonSchema for StatueSlotsMap
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StatueSlotsMap
impl PartialEq for StatueSlotsMap
Sourceimpl Serialize for StatueSlotsMap
impl Serialize for StatueSlotsMap
Sourceimpl Tsify for StatueSlotsMap
impl Tsify for StatueSlotsMap
const DECL: &'static str = "/**\n * \u{41a}\u{430}\u{440}\u{442}\u{430} \u{441}\u{43b}\u{43e}\u{442}\u{43e}\u{432} \u{441}\u{442}\u{430}\u{442}\u{443}\u{438}: \u{43a}\u{43b}\u{44e}\u{447} \u{2014} \u{438}\u{43d}\u{434}\u{435}\u{43a}\u{441} \u{441}\u{43b}\u{43e}\u{442}\u{430}, \u{437}\u{43d}\u{430}\u{447}\u{435}\u{43d}\u{438}\u{435} \u{2014} \u{437}\u{430}\u{43f}\u{43e}\u{43b}\u{43d}\u{435}\u{43d}\u{43d}\u{44b}\u{439} \u{441}\u{43b}\u{43e}\u{442}.\n * \u{41e}\u{442}\u{441}\u{443}\u{442}\u{441}\u{442}\u{432}\u{443}\u{44e}\u{449}\u{438}\u{439} \u{43a}\u{43b}\u{44e}\u{447} \u{43e}\u{437}\u{43d}\u{430}\u{447}\u{430}\u{435}\u{442}, \u{447}\u{442}\u{43e} \u{441}\u{43b}\u{43e}\u{442} \u{435}\u{449}\u{451} \u{43d}\u{435} \u{431}\u{44b}\u{43b} \u{43f}\u{440}\u{43e}\u{43a}\u{430}\u{442}\u{430}\u{43d} (pending).\n */\nexport type StatueSlotsMap = Record<number, StatueBonusSlot>;"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for StatueSlotsMap
impl StructuralPartialEq for StatueSlotsMap